@@ -1,6 +1,7 @@
 mod use_async;
 mod use_before_unload;
 mod use_click_away;
+mod use_clipboard;
 mod use_counter;
 mod use_debounce;
 mod use_debounce_effect;
@@ -54,6 +55,7 @@ mod use_window_size;
 pub use use_async::*;
 pub use use_before_unload::*;
 pub use use_click_away::*;
+pub use use_clipboard::*;
 pub use use_counter::*;
 pub use use_debounce::*;
 pub use use_debounce_effect::*;
